@@ -1,4 +1,4 @@
-/* Sticky Notes 
+/* Sticky Notes
  * Copyright (C) 2002-2003 Loban A Rahman
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,6 @@
 #include "stickynotes_applet_callbacks.h"
 #include "stickynotes.h"
 #include <gdk/gdkkeysyms.h>
-#include <libgnomeui/gnome-help.h>
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
 
@@ -124,10 +123,10 @@ applet_key_cb (GtkWidget         *widget,
 /* Applet Callback : Cross (enter or leave) the applet. */
 gboolean applet_cross_cb(GtkWidget *widget, GdkEventCrossing *event, StickyNotesApplet *applet)
 {
-	applet->prelighted = event->type == GDK_ENTER_NOTIFY || GTK_WIDGET_HAS_FOCUS(widget);
+	applet->prelighted = event->type == GDK_ENTER_NOTIFY || gtk_widget_has_focus(widget);
 
 	stickynotes_applet_update_icon(applet);
-	
+
 	return FALSE;
 }
 
@@ -144,11 +143,11 @@ gboolean applet_focus_cb(GtkWidget *widget, GdkEventFocus *event, StickyNotesApp
 static GdkFilterReturn desktop_window_event_filter (GdkXEvent *xevent,
 						    GdkEvent  *event,
 						    gpointer   data)
-{ 
+{
 	if ((((XEvent*)xevent)->xany.type == PropertyNotify) &&
-	    (((XEvent*)xevent)->xproperty.atom == gdk_x11_get_xatom_by_name ("_NET_WM_USER_TIME"))) { 
+	    (((XEvent*)xevent)->xproperty.atom == gdk_x11_get_xatom_by_name ("_NET_WM_USER_TIME"))) {
 		stickynote_show_notes (FALSE);
-	} 
+	}
 	return GDK_FILTER_CONTINUE;
 }
 
@@ -211,7 +210,7 @@ applet_change_bg_cb (PanelApplet *panel_applet,
 	gtk_widget_set_style (GTK_WIDGET (applet->w_applet), NULL);
 	rc_style = gtk_rc_style_new ();
 	gtk_widget_modify_style (GTK_WIDGET (applet->w_applet), rc_style);
-	gtk_rc_style_unref (rc_style);
+	g_object_unref (rc_style);
 
 	switch (type)
 	{
@@ -223,7 +222,7 @@ applet_change_bg_cb (PanelApplet *panel_applet,
 			break;
 		case PANEL_PIXMAP_BACKGROUND:
 			style = gtk_style_copy (
-					GTK_WIDGET (applet->w_applet)->style);
+					gtk_widget_get_style (GTK_WIDGET (applet->w_applet)));
 			if (style->bg_pixmap[GTK_STATE_NORMAL])
 				g_object_unref (
 					style->bg_pixmap[GTK_STATE_NORMAL]);
@@ -240,7 +239,7 @@ applet_change_bg_cb (PanelApplet *panel_applet,
 void applet_destroy_cb (PanelApplet *panel_applet, StickyNotesApplet *applet)
 {
 	GList *notes;
-	
+
 	stickynotes_save_now ();
 
 	if (applet->destroy_all_dialog != NULL)
@@ -248,7 +247,7 @@ void applet_destroy_cb (PanelApplet *panel_applet, StickyNotesApplet *applet)
 
 	if (stickynotes->applets != NULL)
 		stickynotes->applets = g_list_remove (stickynotes->applets, applet);
-		
+
 	if (stickynotes->applets == NULL) {
                notes = stickynotes->notes;
                while (notes) {
@@ -257,9 +256,9 @@ void applet_destroy_cb (PanelApplet *panel_applet, StickyNotesApplet *applet)
                        notes = g_list_next (notes);
                }
 	}
-	
-	
-}		
+
+
+}
 
 /* Destroy all response Callback: Callback for the destroy all dialog */
 static void
@@ -270,7 +269,7 @@ destroy_all_response_cb (GtkDialog *dialog, gint id, StickyNotesApplet *applet)
 			StickyNote *note = g_list_nth_data(stickynotes->notes, 0);
 			stickynote_free(note);
 			stickynotes->notes = g_list_remove(stickynotes->notes, note);
-		}							       
+		}
 	}
 
 	stickynotes_applet_update_tooltips();
@@ -307,7 +306,7 @@ void menu_destroy_all_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, cons
 		gtk_window_present (GTK_WINDOW (applet->destroy_all_dialog));
 		return;
 	}
-	
+
 	applet->destroy_all_dialog = GTK_WIDGET (gtk_builder_get_object (builder, "delete_all_dialog"));
 
 	g_object_unref (builder);
@@ -341,7 +340,10 @@ void menu_preferences_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, cons
 void menu_help_cb(BonoboUIComponent *uic, StickyNotesApplet *applet, const gchar *verbname)
 {
 	GError *error = NULL;
-	gnome_help_display_on_screen("stickynotes_applet", NULL, gtk_widget_get_screen(applet->w_applet), &error);
+	gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet->w_applet)),
+			"ghelp:stickynotes_applet",
+			gtk_get_current_event_time (),
+			&error);
 	if (error) {
 		GtkWidget *dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 							   _("There was an error displaying help: %s"), error->message);
@@ -440,7 +442,7 @@ preferences_color_cb (GtkWidget *button, gpointer data)
 	gtk_color_button_get_color (
 			GTK_COLOR_BUTTON (stickynotes->w_prefs_font_color),
 			&font_color);
-	
+
 	color_str = g_strdup_printf ("#%.2x%.2x%.2x",
 			color.red / 256,
 			color.green / 256,
@@ -449,7 +451,7 @@ preferences_color_cb (GtkWidget *button, gpointer data)
 			font_color.red / 256,
 			font_color.green / 256,
 			font_color.blue / 256);
-	
+
 	gconf_client_set_string (stickynotes->gconf,
 			GCONF_PATH "/defaults/color", color_str, NULL);
 	gconf_client_set_string (stickynotes->gconf,
@@ -548,7 +550,10 @@ void preferences_response_cb(GtkWidget *dialog, gint response, gpointer data)
 {
 	if (response == GTK_RESPONSE_HELP) {
 		GError *error = NULL;
-		gnome_help_display_on_screen("stickynotes_applet", "stickynotes-advanced-settings", gtk_widget_get_screen(GTK_WIDGET(dialog)), &error);
+		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
+				"ghelp:stickynotes_applet?stickynotes-advanced-settings",
+				gtk_get_current_event_time (),
+				&error);
 		if (error) {
 			dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 								   _("There was an error displaying help: %s"), error->message);
@@ -560,8 +565,8 @@ void preferences_response_cb(GtkWidget *dialog, gint response, gpointer data)
 		}
 	}
 
-	else
-		gtk_widget_hide(GTK_WIDGET(dialog));
+	else if (response == GTK_RESPONSE_CLOSE)
+	        gtk_widget_hide(GTK_WIDGET(dialog));
 }
 
 /* Preferences Callback : Delete */
